@@ -9,10 +9,10 @@ from typing import Any, Callable, ClassVar, Iterator, Mapping, MutableMapping, c
 
 import platformdirs
 import rich.theme
-import tomlkit
 
 from pdm import termui
 from pdm._types import RepositoryConfig
+from pdm.compat import tomllib
 from pdm.exceptions import NoConfigError, PdmUsageError
 
 REPOSITORY = "repository"
@@ -25,6 +25,15 @@ DEFAULT_REPOSITORIES = {
 ui = termui.UI()
 
 
+def choices(*choices: str) -> Callable[[str], str]:
+    def converter(value: str) -> str:
+        if value not in choices:
+            raise ValueError(f"Value must be one of {choices}, got {value!r}")
+        return value
+
+    return converter
+
+
 def load_config(file_path: Path) -> dict[str, Any]:
     """Load a nested TOML document into key-value pairs
 
@@ -42,9 +51,11 @@ def load_config(file_path: Path) -> dict[str, Any]:
                 result.update({k: v})
         return result
 
-    if not file_path.is_file():
+    try:
+        with file_path.open("rb") as fp:
+            return get_item(tomllib.load(fp))
+    except FileNotFoundError:
         return {}
-    return get_item(dict(tomlkit.parse(file_path.read_text("utf-8"))))
 
 
 def ensure_boolean(val: Any) -> bool:
@@ -131,6 +142,12 @@ class Config(MutableMapping[str, str]):
             "PDM_USE_UV",
             ensure_boolean,
         ),
+        "lock.format": ConfigItem(
+            "The format of the lock file, can be `pdm` or `pylock`",
+            "pdm",
+            env_var="PDM_LOCK_FORMAT",
+            coerce=choices("pdm", "pylock"),
+        ),
         "global_project.fallback": ConfigItem(
             "Use the global project implicitly if no local project is found",
             False,
@@ -182,6 +199,12 @@ class Config(MutableMapping[str, str]):
         "python.use_venv": ConfigItem(
             "Use virtual environments when available", True, env_var="PDM_USE_VENV", coerce=ensure_boolean
         ),
+        "python.use_python_version": ConfigItem(
+            "Use .python-version file next to pyproject.toml to find python interpreters",
+            True,
+            env_var="PDM_USE_PYTHON_VERSION",
+            coerce=ensure_boolean,
+        ),
         "python.install_root": ConfigItem(
             "The root directory to install python interpreters",
             global_only=True,
@@ -288,6 +311,12 @@ class Config(MutableMapping[str, str]):
             self.get_defaults() if is_global else {},
         )
 
+    def reload(self) -> None:
+        """Reload the config from file"""
+        new_data = load_config(self.config_file)
+        self._file_data.clear()
+        self._file_data.update(new_data)
+
     def load_theme(self) -> rich.theme.Theme:
         if not self.is_global:  # pragma: no cover
             raise PdmUsageError("Theme can only be loaded from global config")
@@ -303,6 +332,8 @@ class Config(MutableMapping[str, str]):
                 yield RepositoryConfig(**data, name=name[len(SOURCE) + 1 :], config_prefix=SOURCE)
 
     def _save_config(self) -> None:
+        import tomlkit
+
         """Save the changed to config file."""
         self.config_file.parent.mkdir(parents=True, exist_ok=True)
         toml_data: dict[str, Any] = {}
